pub struct Allocation {
pub params: AllocationParams,
pub status: AllocationStatus,
pub user: Addr,
pub block_ts: u64,
}Fields
params: AllocationParamsThe allocation parameters
status: AllocationStatusThe allocation status
user: AddrAllocation owner
block_ts: u64Current block timestamp
Implementations
Sourceimpl Allocation
impl Allocation
pub fn must_load( storage: &dyn Storage, block_ts: u64, user: &Addr, ) -> Result<Self, ContractError>
pub fn save(self, storage: &mut dyn Storage) -> StdResult<()>
pub fn new_allocation( storage: &mut dyn Storage, block_ts: u64, user: &Addr, params: CreateAllocationParams, ) -> Result<Self, ContractError>
pub fn withdraw_and_update(&mut self) -> Result<Uint128, ContractError>
pub fn propose_new_receiver( &mut self, storage: &dyn Storage, new_receiver: &Addr, ) -> Result<(), ContractError>
pub fn drop_proposed_receiver(&mut self) -> Result<Addr, ContractError>
Sourcepub fn claim_allocation(
self,
storage: &mut dyn Storage,
new_receiver: &Addr,
) -> Result<Self, ContractError>
pub fn claim_allocation( self, storage: &mut dyn Storage, new_receiver: &Addr, ) -> Result<Self, ContractError>
Produces new allocation object for new receiver. Old allocation is removed from state.
Sourcepub fn compute_unlocked_amount(&self, timestamp: u64) -> Uint128
pub fn compute_unlocked_amount(&self, timestamp: u64) -> Uint128
Computes number of tokens that are now unlocked for a given allocation
Sourcepub fn compute_withdraw_amount(
&self,
timestamp: u64,
) -> SimulateWithdrawResponse
pub fn compute_withdraw_amount( &self, timestamp: u64, ) -> SimulateWithdrawResponse
Computes number of tokens that are withdrawable for a given allocation
pub fn decrease_allocation( &mut self, amount: Uint128, ) -> Result<(), ContractError>
pub fn increase_allocation( &mut self, amount: Uint128, ) -> Result<(), ContractError>
pub fn update_unlock_schedule( &mut self, new_schedule: &Schedule, ) -> StdResult<()>