pub fn execute(
deps: DepsMut<'_>,
env: Env,
info: MessageInfo,
msg: ExecuteMsg,
) -> Result<Response, ContractError>Expand description
Exposes all the execute functions available in the contract.
Execute messages
-
ExecuteMsg::CreateAllocations Create allocations.
-
ExecuteMsg::Withdraw Withdraw unlocked ASTRO.
-
ExecuteMsg::TransferOwnership Transfer contract ownership.
-
ExecuteMsg::ProposeNewReceiver Propose a new receiver for a specific ASTRO unlock schedule.
-
ExecuteMsg::DropNewReceiver Drop the proposal to change the receiver for an unlock schedule.
-
ExecuteMsg::ClaimReceiver Claim the position as a receiver for a specific unlock schedule.
-
ExecuteMsg::IncreaseAllocation Increase ASTRO allocation for receiver.
-
ExecuteMsg::DecreaseAllocation Decrease ASTRO allocation for receiver.
-
ExecuteMsg::TransferUnallocated Transfer unallocated tokens.
-
ExecuteMsg::ProposeNewOwner Creates a new request to change contract ownership.
-
ExecuteMsg::DropOwnershipProposal Removes a request to change contract ownership.
-
ExecuteMsg::ClaimOwnership Claims contract ownership.
-
ExecuteMsg::UpdateConfig Update contract configuration.